@@ -35,6 +35,7 @@
     "_completed": "Completed",
     "_concept": "Concept",
     "_confirmed": "Confirmed",
+    "_creditHoldType": "Credit Hold",
     "_daily": "Daily",
     "_database": "Database",
     "_databaseInformation": "Database Information",
@@ -54,9 +55,13 @@
     "_monthly": "Monthly",
     "_new": "New",
     "_organization": "Organization",
+    "_packingHoldType": "Packing Hold",
+    "_returnAuthorization": "Return Authorization",
+    "_returnHoldType": "Return Hold",
     "_resolved": "Resolved",
     "_revenue": "Revenue",
     "_salaried": "Salaried",
+    "_shippingHoldType": "Shipping Hold",
     "_systemConfiguration": "System Configuration",
     "_weekly": "Weekly",
 
@@ -223,6 +228,7 @@
     "_debitMemo": "Debit Memo",
     "_default": "Default",
     "_defaultHoldType": "Default Hold Type",
+    "_defaultPrinter": "Default Printer",
     "_defaults": "Defaults",
     "_defaultTaxZone": "Default Tax Zone",
     "_deferred": "Deferred",
@@ -456,6 +462,7 @@
     "_noProjectType": "No Type",
     "_nominal": "Nominal",
     "_noUserSelected": "No User Selected",
+    "_noSched.": "No Sched.",
     "_notControlled": "Not Controlled",
     "_notes": "Notes",
     "_notSold": "Not Sold",
@@ -524,7 +531,10 @@
     "_priceUnitRatio": "Price Unit Ratio",
     "_primaryContact": "Primary Contact",
     "_primaryEmail": "Primary Email",
+    "_printSettings": "Print Settings",
     "_printed": "Printed",
+    "_printer": "Printer",
+    "_printers": "Printers",
     "_printOnSave": "Print on Save",
     "_priority": "Priority",
     "_priorities": "Priorities",
@@ -855,6 +865,7 @@
     "_maintainItemSites": "Maintain Item Sites",
     "_maintainLocations": "Maintain Locations",
     "_maintainPackingListBatch": "Maintain Packing List Batch",
+    "_maintainPrinters": "Maintain Printers",
     "_maintainProductCategories": "Maintain Product Categories",
     "_maintainProspectMasters": "Maintain Prospect Masters",
     "_maintainQuotes": "Maintain Quotes",
