@@ -9,7 +9,7 @@ FOLDER=deploy
 SUFFIX=`date "+-%Y_%m_%d-%I_%M_%S%p"`
 
 # The grandparent folder for this script
-SOURCE=$(cd `dirname $0`/..; pwd)
+SOURCE=$(cd `dirname $0`/../; pwd)
 
 # extract project folder name
 NAME=${SOURCE##*/}
@@ -46,7 +46,7 @@ mkdir -p "$TARGET/lib"
 #cp "$SOURCE/index.html" "$SOURCE/icon.png" "$TARGET"
 
 # copy assets and build
-cp -r "$SOURCE/../../node-datasource/views/login/assets" "$SOURCE/build" "$TARGET"
+cp -r "$SOURCE/../../node-datasource/views/assets" "$SOURCE/build" "$TARGET"
 
 for i in "$SOURCE/lib/"*; do
 	o=${i##*/}
