@@ -3,7 +3,7 @@ select xt.install_js('XM','UserPreference','xtuple', $$
      See www.xm.ple.com/CPAL for the full text of the software license. */
 
   XM.UserPreference = {
-    options: []
+    options: ["PrintSettings"]
   };
 
 $$ );
