@@ -81,7 +81,8 @@ BEGIN
     END IF;
   END IF;
 
-  _gltransNote := _t.checkrecip_number || '-' || _t.checkrecip_name;
+  _gltransNote := _t.checkrecip_number || '-' || _t.checkrecip_name ||
+                  '\n' || _p.checkhead_for || '\n' || _p.checkhead_notes;
 
   IF (_p.checkhead_misc AND NOT _cm) THEN
     IF (COALESCE(_p.checkhead_expcat_id, -1) < 0) THEN
