@@ -207,8 +207,10 @@
     },
 
     doPrint: function (options) {
+      options = options ? options : {};
       XT.dataSource.callRoute("generate-report", this.getReportPayload("print", options), {
         success: function () {
+          // TODO: user may want a notify popup (document type, # and printer) on success.
           console.log("print success");
         }
       });
@@ -541,18 +543,73 @@
     },
 
     getReportUrl: function (action) {
-      var modelName = this.reportRecordType || this.editableModel || this.recordType;
-      return XM.Model.getReportUrl(action, modelName, this.id);
+      var modelName = this.reportRecordType || this.editableModel || this.recordType,
+        auxilliaryInfo,
+        // TODO - move this to the report definition OR forms object/user print pref settings.
+        // Only 'print' one document here because it's an email or a pdf in tab.
+        printQty = null;
+      if (this.requiresDetail() && this.getValue("detail") && this.getValue("detail").length) {
+        auxilliaryInfo = JSON.stringify({
+          detail: _.map(this.getValue("detail").models, function (model) {
+            return {
+              quantity: model.get("quantity"),
+              trace: model.get("trace"),
+              location: model.get("location"),
+              expireDate: Globalize.format(model.get("expireDate"), "d")
+            };
+          })
+        });
+      }
+      return XM.Model.getReportUrl(action, modelName, this.id, printQty, auxilliaryInfo);
     },
 
     getReportPayload: function (action, options) {
-      var modelName = this.reportRecordType || this.editableModel || this.recordType;
+      var modelName = this.reportRecordType || this.editableModel || this.recordType,
+        auxilliaryInfo = this._auxilliaryInfo,
+        /** 
+          TODO - move this to the report definition OR forms object/user print pref settings.
+
+          If 'toIssue', 'toReceive', 'toPost' etc. assume that we're printing the label from the
+          workspace where the user is in the process of posting the qty. Otherwise, get the
+          transacted qty as in printing from a list.
+        */
+        printQty;
+      if (this.quantityAttribute && this.get(this.quantityAttribute) > 0) {
+        printQty = this.get(this.quantityAttribute);
+      } else if (this.quantityTransactedAttribute && this.get(this.quantityTransactedAttribute) > 0) {
+        printQty = this.get(this.quantityTransactedAttribute);
+      } else {
+        printQty = null;
+      }
+      options = options || {}; 
+      /*
+        If _auxilliaryInfo has not been set through enyo and the model requires detail/has detail,
+        then set options.auxilliaryInfo for the generate-report route.
+
+        TODO-refactor ._auxilliaryInfo and below. Choose one way to handle distribution detail obj
+      */
+      if (!auxilliaryInfo && (this.requiresDetail() && this.getValue("detail") &&
+        this.getValue("detail").length)) {
+        auxilliaryInfo = JSON.stringify({
+          detail: _.map(this.getValue("detail").models, function (model) {
+            return {
+              quantity: model.get("quantity"),
+              trace: model.get("trace"),
+              location: model.get("location"),
+              expireDate: Globalize.format(model.get("expireDate"), "d")
+            };
+          })
+        });
+      }
+
       return {
         nameSpace: modelName.prefix(),
         type: modelName.suffix(),
         id: this.id,
-        auxilliaryInfo: options,
-        action: action
+        auxilliaryInfo: auxilliaryInfo,
+        action: action,
+        printer: options.printer,
+        printQty: printQty
       };
     },
 
@@ -757,6 +814,14 @@
       model.on(evt, replaceId);
     },
 
+    /** 
+      Used on inventory transaction models. 
+      Default to false to ease printing handling of (inv. trans.) distribution detail.
+    */
+    requiresDetail: function () {
+      return false;
+    },
+
     /**
       Revert a model back to its original state the last time it was fetched.
     */
@@ -1178,7 +1243,12 @@
             if (isRel && value.models) {
               for (i = 0; i < value.models.length; i++) {
                 model = value.models[i];
-                if (!(model._prevStatus & XM.Model.DESTROYED)) {
+                /*
+                  https://github.com/xtuple/xtuple/pull/1964
+                  Document associations are stored "wrong" on the client. Don't bother validating them.
+                  `data.sql` will clean them up.
+                */
+                if (!(model._prevStatus & XM.Model.DESTROYED) && model.recordType !== "XM.DocumentAssociation") {
                   result = model.validate(model.attributes, options);
                   if (result) { return result; }
                 }
