@@ -5,17 +5,30 @@
 (function () {
   'use strict';
 
+  Object.observe = undefined;
+
   /**
     Abstract check for attribute level privilege access.
 
     @private
   */
   var _canDoAttr = function (action, attribute) {
-    var priv = this.privileges &&
+    var privObject = this.privileges &&
       this.privileges.attribute &&
-      this.privileges.attribute[attribute] &&
-      !_.isUndefined(this.privileges.attribute[attribute][action]) ?
-      this.privileges.attribute[attribute][action] : undefined;
+      this.privileges.attribute[attribute];
+
+    // shim: the way to set an attribute to be non-editable after persist is {update: "false"}
+    // if someone is asking if we can update a READY_NEW model, they're going to be asking
+    // canEdit, which will map to update, but we really know they are interested in the `create`
+    // attribute of the privObject
+    if (privObject && action === "update" && this.isNew() &&
+        privObject.create !== privObject.update) {
+      action = "create";
+    }
+
+    var priv = privObject &&
+      !_.isUndefined(privObject[action]) ?
+      privObject[action] : undefined;
 
     // If there was a privilege then check our access, otherwise assume we have it
     var hasPriv = !_.isUndefined(priv) ? XT.session.getPrivileges().get(priv) : true;
@@ -1483,13 +1496,19 @@
     and privilege control functions.
   */
   XM.ModelClassMixin = {
-    getReportUrl: function (action, modelName, id) {
+    getReportUrl: function (action, modelName, id, printQty, auxilliaryInfo) {
       var reportUrl = "/generate-report?nameSpace=%@&type=%@&id=%@".f(
         modelName.prefix(), modelName.suffix(), id);
 
       if (action) {
         reportUrl = reportUrl + "&action=" + action;
       }
+      if (printQty) {
+        //reportUrl = reportUrl + "&printQty=" + printQty;
+      }
+      if (auxilliaryInfo) {
+        reportUrl = reportUrl + "&auxilliaryInfo=" + auxilliaryInfo;
+      }
       return reportUrl;
     },
 
