@@ -1,8 +1,6 @@
 enyo.depends(
   "date_format/date_format.js",
   "gts-plugins/DatePicker",
-  "nvd3/lib/d3.v3.js",
-  "nvd3/nv.d3.min.js",
   "font-onyx/lib/Icon.js",
   "font-onyx/lib/IconButton.js",
   "font-onyx/lib/TextIcon.js"
