@@ -78,8 +78,8 @@ trailing:true*/
                icon: "time",
                ontap: "showHistory", content: "_history".loc()},
             {kind: "font.TextIcon", name: "searchIconButton",
-               icon: "search",
-               ontap: "showParameters", content: "_search".loc(), showing: false},
+               icon: "search", ontap: "showParameters",
+               content: "_search".loc(), showing: false},
             {kind: "font.TextIcon", name: "helpIconButton",
                icon: "question",
                ontap: "showHelp", content: "_help".loc()}
@@ -137,13 +137,12 @@ trailing:true*/
             {kind: "font.TextIcon", icon: "share", content: "_export".loc()},
             {kind: "onyx.Menu", name: "exportMenu", floating: true}
           ]},
+          {kind: "XV.SortPopup", name: "sortPopup", showing: false},
           {name: "search", kind: "onyx.InputDecorator",
-            showing: false, components: [
-            {name: 'searchInput', kind: "onyx.Input", classes: "xv-search",
+            showing: false, classes: "xv-search", components: [
+            {name: 'searchInput', kind: "onyx.Input",
               placeholder: "_search".loc(), onchange: "inputChanged"},
-            {kind: "Image", src: "/assets/search-input-search.png",
-              name: "searchJump", ontap: "jump"},
-            {kind: "XV.SortPopup", name: "sortPopup", showing: false}
+            {tag: "i", classes: "icon-search", name: "searchJump", ontap: "jump"}
           ]}
         ]},
         {name: "messageHeader"},
@@ -292,7 +291,7 @@ trailing:true*/
         });
       });
       exportMenu.render();
-      this.$.exportButton.setShowing(actions.length);
+      this.$.exportButton.setShowing(actions.length && !enyo.Panels.isScreenNarrow());
 
       // HANDLE SORT BUTTON
       // if the activepanel is a list of some kind, show the button
@@ -988,11 +987,6 @@ trailing:true*/
         XT.error("Don't know what to do with this panel status");
       }
 
-      // If we're already here, bail
-      if (contentPanels.index === this.$.contentPanels.indexOfChild(panel)) {
-        return;
-      }
-
       // cache any extraneous content panels
       this.cachePanels();
 
@@ -1045,7 +1039,7 @@ trailing:true*/
 
       // If this is a mobile device and we're not selecting
       // the welcome screen.
-      if (enyo.Panels.isScreenNarrow() && panelIndex) {
+      if (enyo.Panels.isScreenNarrow()) {
         this.next();
       }
     },
@@ -1057,22 +1051,25 @@ trailing:true*/
       this.$.header.setShowing(!!content);
       this.$.header.setContent(content);
     },
+
     setMenuPanel: function (index) {
       var label = index ? "_back".loc() : "_logout".loc();
       this.$.menuPanels.setIndex(index);
-      this.$.menuPanels.getActive().select(0);
-      this.setContentPanel(0);
+      // If this is a small device, don't automatically select a menu
+      if (!enyo.Panels.isScreenNarrow()) {
+        this.$.menuPanels.getActive().select(0);
+        this.setContentPanel(0);
+      }
       // this causes the gear menu to reload when the module
       // is chosen, rather than just when a content panel is selected
       this.buildMenus();
-
       this.$.backButton.setContent(label);
+      // Only show this back button on small devices
       this.$.backPanelButton.setContent(label);
       this.$.backPanelButton.setShowing(enyo.Panels.isScreenNarrow());
-      this.$.refreshButton.setShowing(index);
-      // TODO: do not show search on small devices
-      //this.$.search.setShowing(index && !enyo.Panels.isScreenNarrow());
-      this.$.search.setShowing(index);
+      this.$.refreshButton.setShowing(!!index);
+      // remove unnecessary buttons on small devices
+      this.$.search.setShowing(!!index && !enyo.Panels.isScreenNarrow());
       this.$.contentToolbar.resized();
     },
     setMessageContent: function (inSender, inEvent) {
@@ -1148,7 +1145,7 @@ trailing:true*/
     */
     panelTap: function (inSender, inEvent) {
       var index = inEvent.index, validIndex = index || index === 0;
-      if (validIndex && inSender.isSelected(index)) { // make sure an item in the list was clicked and is selected
+      if (validIndex) { // make sure an item in the list was clicked
         this.setContentPanel(index);
       }
     },
