@@ -52,11 +52,9 @@ trailing:true, white:true*/
       ]},
       {name: "chartTitleBar", classes: "chart-title-bar", components: [
         {name: "chartTitle", classes: "chart-title"},
-        {kind: "onyx.IconButton", name: "removeIcon",
-          src: "/assets/remove-icon.png", ontap: "chartRemoved",
-          classes: "remove-icon", showing: false}
+        {kind: 'font.IconButton', name: "removeIcon", icon: "remove",
+          showing: false, ontap: "chartRemoved", classes: "remove-icon"}
       ]},
-
       {name: "chartWrapper", classes: "chart-bottom", components: [
         {name: "chart", components: [
           {name: "svg", tag: "svg"} // this is the DOM element that d3 will take over
@@ -247,7 +245,6 @@ trailing:true, white:true*/
       var that = this;
 
       if (!this.getValue() ||
-          !this.getValue().length ||
           !this.getFilterAttr() ||
           this.getGroupByAttr() === undefined ||
           this.getGroupByAttr() === null) {
@@ -314,8 +311,8 @@ trailing:true, white:true*/
   });
 
   enyo.kind(
-    /** @lends XV.DrilldownBarChart */{
-    name: "XV.DrilldownBarChart",
+    /** @lends XV.DrilldownChart */{
+    name: "XV.DrilldownChart",
     kind: "XV.SelectableChart",
     filterOptions: [
       { name: "all", parameters: [] }
@@ -397,7 +394,13 @@ trailing:true, white:true*/
         });
 
       return filterOption.parameters;
-    },
+    }
+  });
+
+  enyo.kind(
+    /** @lends XV.DrilldownBarChart */{
+    name: "XV.DrilldownBarChart",
+    kind: "XV.DrilldownChart",
     /**
       Make the chart using v3 and nv.d3, working off our this.processedData.
      */
@@ -405,7 +408,6 @@ trailing:true, white:true*/
       var that = this,
         div = this.$.svg.hasNode();
 
-      //nv.addGraph(function () {
       var chart = nv.models.discreteBarChart()
         .x(function (d) { return d.label; })
         .y(function (d) { return d.value; })
@@ -427,9 +429,7 @@ trailing:true, white:true*/
       d3.selectAll(".nv-bar").on("click", function (bar, index) {
         that.drillDown(that.getGroupByAttr(), bar.label);
       });
-
       // to set text style: d3.selectAll("text").style("fill", "white");
-
     }
   });
 
@@ -441,11 +441,7 @@ trailing:true, white:true*/
       dateField: ""
     },
     filterOptions: [
-      { name: "thisWeek" },
-      { name: "thisMonth" },
-      { name: "thisYear" },
-      { name: "twoYears" },
-      { name: "fiveYears" }
+      { name: "all", parameters: [] }
     ],
     /**
       This looks really complicated! I'm just binning the
@@ -454,16 +450,18 @@ trailing:true, white:true*/
     aggregateData: function (groupedData) {
       var that = this,
         now = new Date().getTime(),
-        earliestDate = now, // won't be now for long
+        earliestDate = now, // might not be now for long
+        latestDate = now, // might not be now for long
         dataPoints = _.reduce(groupedData, function (memo, group) {
           _.each(group, function (item) {
             var dateInt = item.get(that.getDateField()).getTime();
             earliestDate = Math.min(earliestDate, dateInt);
+            latestDate = Math.max(latestDate, dateInt);
           });
           return memo + group.length;
         }, 0),
         binCount = Math.ceil(Math.sqrt(dataPoints)),
-        binWidth = Math.ceil((now - earliestDate) / binCount),
+        binWidth = Math.ceil((latestDate - earliestDate) / binCount),
         histoGroup = _.map(groupedData, function (group, groupKey) {
           var binnedData, summedData, hole, findHole, foundData;
 
@@ -482,7 +480,7 @@ trailing:true, white:true*/
           findHole = function (datum) {
             return datum.x === String(hole);
           };
-          for (hole = earliestDate; hole <= now; hole += binWidth) {
+          for (hole = earliestDate; hole <= latestDate; hole += binWidth) {
             foundData = _.find(summedData, findHole);
             if (!foundData) {
               summedData.push({x: String(hole), y: 0});
@@ -497,39 +495,6 @@ trailing:true, white:true*/
 
       return histoGroup;
     },
-    filterData: function (data, callback) {
-      var that = this;
-
-      callback(_.filter(data, function (datum) {
-        var shipDate = datum.get(that.getDateField()).getTime(),
-          now = new Date().getTime(),
-          timespan = 0,
-          oneDay = 1000 * 60 * 60 * 24;
-
-        // XXX use YTD etc.?
-        switch (that.getFilterAttr()) {
-        case "today":
-          timespan = oneDay;
-          break;
-        case "thisWeek":
-          timespan = 7 * oneDay;
-          break;
-        case "thisMonth":
-          timespan = 30 * oneDay;
-          break;
-        case "thisYear":
-          timespan = 365 * oneDay;
-          break;
-        case "twoYears":
-          timespan = 2 * 365 * oneDay;
-          break;
-        case "fiveYears":
-          timespan = 5 * 365 * oneDay;
-          break;
-        }
-        return shipDate + timespan >= now;
-      }));
-    },
     /**
       Make the chart using v3 and nv.d3, working off our this.processedData.
      */
@@ -566,45 +531,27 @@ trailing:true, white:true*/
     },
   });
 
-  // This one ended up not looking good for sales history, but it might
-  // be useful somewhere else
-  /*
   enyo.kind({
-    name: "XV.TimeSeriesLineChart",
-    kind: "XV.SelectableChart",
-    published: {
-      dateField: ""
-    },
-    aggregateData: function (groupedData) {
-      var that = this;
-
-      return _.map(groupedData, function (group, key) {
-        var groupValues = _.map(group, function (modelData) {
-          return {
-            x: modelData.get(that.getDateField()).getTime(),
-            y: modelData.get(that.getTotalField())
-          };
-        });
-
-        return {
-          key: key,
-          values: groupValues
-        };
-      });
-    },
+    name: "XV.DrilldownPieChart",
+    kind: "XV.DrilldownChart",
     plot: function () {
+
       var that = this,
         div = this.$.svg.hasNode();
 
-      var chart = nv.models.lineChart();
-      chart.xAxis
-        .tickFormat(function (d) { return d3.time.format('%b %d %y')(new Date(d)); });
+      var chart = nv.models.pieChart()
+        .x(function (d) { return d.label; })
+        .y(function (d) { return d.value; })
+        .showLabels(true);
 
       d3.select(div)
-        .datum(this.getProcessedData())
+        .datum(this.getProcessedData()[0].values)
         .transition().duration(500)
         .call(chart);
+
+      d3.selectAll(".nv-slice").on("click", function (slice, index) {
+        that.drillDown(that.getGroupByAttr(), slice.data.label);
+      });
     },
   });
-  */
 }());
