@@ -46,8 +46,6 @@ regexp:true, undef:true, trailing:true, white:true */
      */
     datePicked: function (inSender, inEvent) {
       var date = inEvent, options = {};
-      // mimic the human-typed behavior
-      this.applyTimezoneOffset(date);
 
       options.silent = true;
       this.setValue(date, options);
