@@ -10,8 +10,10 @@ _ = require("underscore");
 jsonpatch = require("json-patch");
 SYS = {};
 XT = { };
-var express = require('express');
-var app;
+
+var express = require('express'),
+  async = require("async"),
+  app;
 
 (function () {
   "use strict";
@@ -91,10 +93,24 @@ var app;
     }
   });
 
-
   XT.session = Object.create(XT.Session);
   XT.session.schemas.SYS = false;
 
+  // Load the Database hostname and port into metrics to enable Qt client deep linking
+  X.options.datasource.databases.map(function (database) {
+    var queryPayload,
+      query = "SELECT setmetric('%@', '%@');";
+
+    queryPayload = query.f('WebappHostname', X.options.datasource.hostname);
+    XT.dataSource.query(queryPayload, XT.dataSource.getAdminCredentials(database), function (error, res) {
+      if (error) { console.log("An error occurred writing the hostname to the metric table " + error); }
+    });
+    queryPayload = query.f('WebappPort', X.options.datasource.port);
+    XT.dataSource.query(queryPayload, XT.dataSource.getAdminCredentials(database), function (error, res) {
+      if (error) { console.log("An error occurred writing the port to the metric table" + error); }
+    });
+  });
+
   var getExtensionDir = function (extension) {
     var dirMap = {
       "/private-extensions": X.path.join(__dirname, "../..", extension.location, "source", extension.name),
@@ -112,11 +128,20 @@ var app;
   };
   var loadExtensionClientside = function (extension) {
     var extensionLocation = extension.location === "npm" ? extension.location : extension.location + "/source";
+    // add static assets in client folder
     useClientDir(extensionLocation + "/" + extension.name + "/client", X.path.join(getExtensionDir(extension), "client"));
+    // add static assets in public folder
+    useClientDir(extensionLocation + "/" + extension.name + "/public", X.path.join(getExtensionDir(extension), "public"));
   };
-  var loadExtensionRoutes = function (extension) {
-    var manifest = JSON.parse(X.fs.readFileSync(X.path.join(getExtensionDir(extension),
-        "database/source/manifest.js")));
+  var loadExtensionServerside = function (extension) {
+    var packagePath = X.path.join(getExtensionDir(extension), "package.json");
+    var packageJson = X.fs.existsSync(packagePath) ? require(packagePath) : undefined;
+    var manifestPath = X.path.join(getExtensionDir(extension), "database/source/manifest.js");
+    var manifest = X.fs.existsSync(manifestPath) ? JSON.parse(X.fs.readFileSync(manifestPath)) : {};
+    var version = packageJson ? packageJson.version : manifest.version;
+    X.versions[extension.name] = version || "none"; // XXX the "none" is temporary until we have core extensions in npm
+
+    // TODO: be able to define routes in package.json
     _.each(manifest.routes || [], function (routeDetails) {
       var verb = (routeDetails.verb || "all").toLowerCase(),
         func = require(X.path.join(getExtensionDir(extension),
@@ -124,8 +149,10 @@ var app;
 
       if (_.contains(["all", "get", "post", "patch", "delete"], verb)) {
         app[verb]('/:org/' + routeDetails.path, func);
+      } else if (verb === "no-route") {
+        func();
       } else {
-        console.log("Invalid verb for extension-defined route " + routeDetails.path);
+        console.log("Invalid verb (" + verb + ") for extension-defined route " + routeDetails.path);
       }
     });
   };
@@ -149,7 +176,7 @@ var app;
           return;
         }
         useClientDir("/client", "../enyo-client/application");
-        _.each(results, loadExtensionRoutes);
+        _.each(results, loadExtensionServerside);
         _.each(results, loadExtensionClientside);
       }
     });
@@ -160,6 +187,33 @@ var app;
   privSessionOptions.database = X.options.datasource.databases[0];
   XT.session.loadSessionObjects(XT.session.PRIVILEGES, privSessionOptions);
 
+  var cacheCount = 0;
+  var cacheShareUsersWarmed = function (err, result) {
+    if (err) {
+      console.trace("Share Users Cache warming errors:");
+    } else {
+      cacheCount++;
+      if (cacheCount === X.options.datasource.databases.length) {
+        X.log("All Share Users Caches have been warmed.");
+      }
+    }
+  };
+
+  var warmCacheShareUsers = function (dbVal, callback) {
+    var cacheShareUsersOptions = {
+      user: X.options.databaseServer.user,
+      port: X.options.databaseServer.port,
+      hostname: X.options.databaseServer.hostname,
+      database: dbVal,
+      password: X.options.databaseServer.password
+    };
+
+    X.log("Warming Share Users Cache for database " + dbVal + "...");
+    datasource.api.query('select xt.refresh_share_user_cache()', cacheShareUsersOptions, cacheShareUsersWarmed);
+  };
+
+  async.map(X.options.datasource.databases, warmCacheShareUsers);
+
 }());
 
 
@@ -168,11 +222,9 @@ var app;
  */
 
 var packageJson = X.fs.readFileSync("../package.json");
-try {
-  X.version = JSON.parse(packageJson).version;
-} catch (error) {
-
-}
+X.versions = {
+  core: JSON.parse(packageJson).version
+};
 
 /**
  * Module dependencies.
@@ -291,10 +343,13 @@ var conditionalExpressSession = function (req, res, next) {
   // The 'assets' folder and login page are sessionless.
   if ((/^api/i).test(req.path.split("/")[2]) ||
       (/^\/assets/i).test(req.path) ||
-      req.path === "/" ||
-      req.path === "/favicon.ico" ||
-      req.path === "/forgot-password" ||
-      req.path === "/recover") {
+      (/^\/stylesheets/i).test(req.path) ||
+      (/^\/bower_components/i).test(req.path) ||
+      req.path === '/' ||
+      req.path === '/favicon.ico' ||
+      req.path === '/forgot-password' ||
+      req.path === '/assets' ||
+      req.path === '/recover') {
 
     next();
   } else {
@@ -391,8 +446,11 @@ require('./oauth2/passport');
  */
 var that = this;
 
-app.use(express.favicon(__dirname + '/views/login/assets/favicon.ico'));
-app.use('/assets', express.static('views/login/assets', { maxAge: 86400000 }));
+/* Static assets */
+app.use(express.favicon(__dirname + '/views/assets/favicon.ico'));
+app.use('/assets', express.static('views/assets', { maxAge: 86400000 }));
+app.use('/stylesheets', express.static('views/stylesheets', { maxAge: 86400000 }));
+app.use('/bower_components', express.static('../bower_components', { maxAge: 86400000 }));
 
 app.get('/:org/dialog/authorize', oauth2.authorization);
 app.post('/:org/dialog/authorize/decision', oauth2.decision);
@@ -409,6 +467,11 @@ app.all('/:org/api/v1alpha1/resources/:model/:id', routes.restRouter);
 app.all('/:org/api/v1alpha1/resources/:model', routes.restRouter);
 app.all('/:org/api/v1alpha1/resources/*', routes.restRouter);
 
+app.post('/:org/browser-api/v1/services/:service/:id', routes.restBrowserRouter);
+app.all('/:org/browser-api/v1/resources/:model/:id', routes.restBrowserRouter);
+app.all('/:org/browser-api/v1/resources/:model', routes.restBrowserRouter);
+app.all('/:org/browser-api/v1/resources/*', routes.restBrowserRouter);
+
 app.get('/', routes.loginForm);
 app.post('/login', routes.login);
 app.get('/forgot-password', routes.forgotPassword);
@@ -436,7 +499,6 @@ app.get('/:org/reset-password', routes.resetPassword);
 app.post('/:org/oauth/revoke-token', routes.revokeOauthToken);
 app.all('/:org/vcfExport', routes.vcfExport);
 
-
 // Set up the other servers we run on different ports.
 
 var redirectServer = express();
@@ -638,10 +700,10 @@ io.of('/clientsock').authorization(function (handshakeData, callback) {
           data: session.passport.user,
           code: 1,
           debugging: X.options.datasource.debugging,
-          biAvailable: _.isObject(X.options.biServer) && !_.isEmpty(X.options.biServer),
           emailAvailable: _.isString(X.options.datasource.smtpHost) && X.options.datasource.smtpHost !== "",
+          // TODO - printAvailable is deprecated after issues #1806 & #1807 are pulled in.
           printAvailable: _.isString(X.options.datasource.printer) && X.options.datasource.printer !== "",
-          version: X.version
+          versions: X.versions
         });
       callback(callbackObj);
     }, data && data.payload);
