@@ -5,14 +5,17 @@ regexp:true, undef:true, strict:true, trailing:true, white:true */
 var _ = require('underscore'),
   async = require('async'),
   buildDatabase = require("./build_database"),
-  buildDatabaseUtil = require("./build_database_util"),
+  buildDictionary = require("./build_dictionary"),
   buildClient = require("./build_client").buildClient,
+  defaultExtensions = require("./util/default_extensions").extensions,
   dataSource = require('../../node-datasource/lib/ext/datasource').dataSource,
   exec = require('child_process').exec,
   fs = require('fs'),
+  initDatabase = require("./util/init_database").initDatabase,
+  inspectDatabaseExtensions = require("./util/inspect_database").inspectDatabaseExtensions,
   npm = require('npm'),
   path = require('path'),
-  unregister = buildDatabaseUtil.unregister,
+  unregister = require("./util/unregister").unregister,
   winston = require('winston');
 
 /*
@@ -31,108 +34,139 @@ var _ = require('underscore'),
 
   var creds;
 
+  var buildAll = function (specs, creds, buildAllCallback) {
+    async.series([
+      function (done) {
+        // step 0: init the database, if requested
+
+        if (specs.length === 1 &&
+            specs[0].initialize &&
+            (specs[0].backup || specs[0].source)) {
+
+          // The user wants to initialize the database first (i.e. Step 0)
+          // Do that, then call this function again
+          initDatabase(specs[0], creds, function (err, res) {
+            specs[0].wasInitialized = true;
+            done(err, res);
+          });
+          return;
+        } else {
+          done();
+        }
+
+      },
+      function (done) {
+        if (specs[0].npmDev) {
+          done();
+          return;
+        }
+        // step 1: npm install extension if necessary
+        // an alternate approach would be only npm install these
+        // extensions on an npm install.
+        var allExtensions = _.reduce(specs, function (memo, spec) {
+          memo.push(spec.extensions);
+          return _.flatten(memo);
+        }, []);
+        var npmExtensions = _.filter(allExtensions, function (extName) {
+          return extName && extName.indexOf("node_modules") >= 0;
+        });
+        if (npmExtensions.length === 0) {
+          done();
+          return;
+        }
+        npm.load(function (err, res) {
+          if (err) {
+            done(err);
+            return;
+          }
+          npm.on("log", function (message) {
+            // log the progress of the installation
+            console.log(message);
+          });
+          async.map(npmExtensions, function (extName, next) {
+            npm.commands.install([path.basename(extName)], next);
+          }, done);
+        });
+      },
+      function (done) {
+        // step 2: build the client
+        buildClient(specs, done);
+      },
+      function (done) {
+        // step 3: build the database
+        buildDatabase.buildDatabase(specs, creds, function (databaseErr, databaseRes) {
+          if (databaseErr) {
+            buildAllCallback(databaseErr);
+            return;
+          }
+          var returnMessage = "\n";
+          _.each(specs, function (spec) {
+            returnMessage += "Database: " + spec.database + '\nDirectories:\n';
+            _.each(spec.extensions, function (ext) {
+              returnMessage += '  ' + ext + '\n';
+            });
+          });
+          done(null, "Build succeeded." + returnMessage);
+        });
+      },
+      function (done) {
+        // step 4: import all dictionary files
+        if (specs[0].clientOnly || specs[0].databaseOnly) {
+          // don't build dictionaries if the user doesn't want us to
+          console.log("Not importing the dictionaries");
+          return done();
+        }
+        if (specs[0].extensions.length === 1 && specs[0].extensions[0].indexOf("foundation-database") >= 0) {
+          // don't build dictionaries if we're just building the foundation
+          console.log("Not importing the dictionaries");
+          return done();
+        }
+        var dictionaryOptionsArray = _.map(specs, function (spec) {
+          return {
+            configPath: spec.configPath,
+            database: spec.database
+          };
+        });
+        async.map(dictionaryOptionsArray, buildDictionary.importAllDictionaries, done);
+      }
+    ], function (err, results) {
+      buildAllCallback(err, results && results[results.length - 2]);
+    });
+  };
 
   exports.build = function (options, callback) {
     var buildSpecs = {},
       databases = [],
       extension,
+      configPath = options.config ?
+        path.resolve(process.cwd(), options.config) :
+        path.resolve(__dirname, "../../node-datasource/config.js"),
+      config = require(configPath),
       getRegisteredExtensions = function (database, callback) {
         var credsClone = JSON.parse(JSON.stringify(creds));
         credsClone.database = database;
-        buildDatabaseUtil.inspectDatabaseExtensions(credsClone, function (err, paths) {
-          callback(null, {
+        inspectDatabaseExtensions(credsClone, function (err, paths) {
+          callback(err, {
             extensions: paths,
+            configPath: configPath,
             database: database,
             keepSql: options.keepSql,
-            populateData: options.populateData,
+            npmDev: options.npmDev,
+            // populate the data if you're explicitly asked to
+            // or if it's a demo build
+            // but even if it's a demo build, don't populate the
+            // data if it's a plv8-free build
+            populateData: options.populateData ||
+              (options.source &&
+              options.source.indexOf("postbooks_demo_data.sql") >= 0 &&
+              !_.isEqual(options.extensions, ["foundation-database"])),
             wipeViews: options.wipeViews,
             clientOnly: options.clientOnly,
             databaseOnly: options.databaseOnly
           });
         });
-      },
-      buildAll = function (specs, creds, buildAllCallback) {
-        async.series([
-          function (done) {
-            // step 0: init the database, if requested
+      };
 
-            if (specs.length === 1 &&
-                specs[0].initialize &&
-                (specs[0].backup || specs[0].source)) {
-
-              // The user wants to initialize the database first (i.e. Step 0)
-              // Do that, then call this function again
-              buildDatabaseUtil.initDatabase(specs[0], creds, function (err, res) {
-                specs[0].wasInitialized = true;
-                done(err, res);
-              });
-              return;
-            } else {
-              done();
-            }
-
-          },
-          function (done) {
-            // step 1: npm install extension if necessary
-            // an alternate approach would be only npm install these
-            // extensions on an npm install.
-            var allExtensions = _.reduce(specs, function (memo, spec) {
-              memo.push(spec.extensions);
-              return _.flatten(memo);
-            }, []);
-            var npmExtensions = _.filter(allExtensions, function (extName) {
-              return extName && extName.indexOf("node_modules") >= 0;
-            });
-            if (npmExtensions.length === 0) {
-              done();
-              return;
-            }
-            npm.load(function (err, res) {
-              if (err) {
-                done(err);
-                return;
-              }
-              npm.on("log", function (message) {
-                // log the progress of the installation
-                console.log(message);
-              });
-              async.map(npmExtensions, function (extName, next) {
-                npm.commands.install([path.basename(extName)], next);
-              }, done);
-            });
-          },
-          function (done) {
-            // step 2: build the client
-            buildClient(specs, done);
-          },
-          function (done) {
-            // step 3: build the database
-            buildDatabase.buildDatabase(specs, creds, function (databaseErr, databaseRes) {
-              if (databaseErr) {
-                buildAllCallback(databaseErr);
-                return;
-              }
-              var returnMessage = "\n";
-              _.each(specs, function (spec) {
-                returnMessage += "Database: " + spec.database + '\nDirectories:\n';
-                _.each(spec.extensions, function (ext) {
-                  returnMessage += '  ' + ext + '\n';
-                });
-              });
-              done(null, "Build succeeded." + returnMessage);
-            });
-          }
-        ], function (err, results) {
-          buildAllCallback(err, results && results[results.length - 1]);
-        });
-      },
-      config;
-
-    if (options.config) {
-      config = require(path.resolve(process.cwd(), options.config));
-    } else {
-      config = require(path.resolve(__dirname, "../../node-datasource/config.js"));
-    }
     creds = config.databaseServer;
     creds.encryptionKeyFile = config.datasource.encryptionKeyFile;
     creds.host = creds.hostname; // adapt our lingo to node-postgres lingo
@@ -176,11 +210,16 @@ var _ = require('underscore'),
         // an unmobilized build
         buildSpecs.extensions = options.extension ?
           [options.extension] :
-          buildDatabaseUtil.defaultExtensions;
+          defaultExtensions;
       }
+      buildSpecs.configPath = configPath;
       buildSpecs.initialize = true;
       buildSpecs.keepSql = options.keepSql;
-      buildSpecs.populateData = options.populateData;
+      buildSpecs.npmDev = options.npmDev;
+      buildSpecs.populateData = options.populateData ||
+        (options.source &&
+         options.source.indexOf("postbooks_demo_data.sql") >= 0 &&
+         options.extension !== "foundation-database");
       buildSpecs.wipeViews = options.wipeViews;
       buildSpecs.clientOnly = options.clientOnly;
       buildSpecs.databaseOnly = options.databaseOnly;
@@ -197,10 +236,13 @@ var _ = require('underscore'),
       buildSpecs = _.map(databases, function (database) {
         var extension = path.resolve(process.cwd(), options.extension);
         return {
+          configPath: configPath,
           database: database,
           frozen: options.frozen,
+          npmDev: options.npmDev,
           keepSql: options.keepSql,
-          populateData: options.populateData,
+          populateData: options.populateData ||
+            (options.source && options.source.indexOf("postbooks_demo_data.sql") >= 0),
           wipeViews: options.wipeViews,
           clientOnly: options.clientOnly,
           databaseOnly: options.databaseOnly,
