@@ -201,14 +201,14 @@ if (typeof XT === 'undefined') {
               source: stringObj.value,
               target: preExistingTranslation
             });
-	  } else if ( destinationLang.indexOf('en') === 0 ) {
-	     // if locale is en_AU en_GB copy the en_US source: strings to target:
-	     stringCallback(null, {
-                key: stringObj.key,
-                source: stringObj.value,
-                target: stringObj.value
-              });
-	  } else {
+          } else if ( destinationLang.indexOf('en') === 0 ) {
+             // if locale is en_AU en_GB copy the en_US source: strings to target:
+             stringCallback(null, {
+               key: stringObj.key,
+               source: stringObj.value,
+               target: stringObj.value
+             });
+          } else {
             // ask google (or not)
             autoTranslate(stringObj.value, apiKey, destinationLang, function (err, target) {
               stringCallback(null, {
@@ -217,7 +217,7 @@ if (typeof XT === 'undefined') {
                 target: target
               });
             });
-         };
+         }
         };
         async.map(stringsArray, processString, function (err, strings) {
           extensionCallback(null, {
@@ -262,14 +262,13 @@ if (typeof XT === 'undefined') {
   /**
     Takes a dictionary definition file and inserts the data into the database
    */
-  exports.importDictionary = function (database, filename, masterCallback) {
-    var creds = require("../../node-datasource/config").databaseServer;
+  var importDictionary = exports.importDictionary = function (options, masterCallback) {
+    var database = options.database;
+    var filename = options.filename;
+    var creds = require(options.configPath || "../../node-datasource/config").databaseServer;
     creds.database = database;
 
-    // the filename relative unless it starts with a slash
-    if (filename.substring(0, 1) !== '/') {
-      filename = path.join(process.cwd(), filename);
-    }
+    filename = path.resolve(process.cwd(), filename);
     if (path.extname(filename) !== '.js') {
       console.log("Skipping non-dictionary file", filename);
       masterCallback();
@@ -299,4 +298,20 @@ if (typeof XT === 'undefined') {
     });
   };
 
+  exports.importAllDictionaries = function (options, callback) {
+    var translationsDir = path.join(__dirname, "../../node_modules/xtuple-linguist/translations");
+    if (!fs.existsSync(translationsDir)) {
+      console.log("No translations directory found. Ignoring linguist.");
+      return callback();
+    }
+    var importOne = function (dictionary, next) {
+      importDictionary({database: options.database, filename: dictionary, configPath: options.configPath}, next);
+    };
+    var allDictionaries = _.map(fs.readdirSync(translationsDir), function (filename) {
+      return path.join(translationsDir, filename);
+    });
+    async.map(allDictionaries, importOne, callback);
+  };
+
+
 }());
