@@ -5,27 +5,11 @@
     assert = require("chai").assert;
 
   var navigateToList = exports.navigateToList = function (app, listKind) {
-    var navigator = app.$.postbooks.$.navigator,
-      myModuleIndex,
-      myPanelIndex;
+    var navigator = XV.navigateToList(app, listKind);
 
-    //
-    // Drill down into the appropriate module
-    //
-    _.each(navigator.modules, function (module, moduleIndex) {
-      _.each(module.panels, function (panel, panelIndex) {
-        if (listKind && panel.kind === listKind) {
-          myModuleIndex = moduleIndex;
-          myPanelIndex = panelIndex;
-        }
-      });
-    });
-    assert.isDefined(myPanelIndex, "Cannot find " + listKind + " in any module panels");
-    navigator.setModule(myModuleIndex);
-    navigator.setContentPanel(myPanelIndex);
+    assert.isObject(navigator, "Cannot find " + listKind + " in any module panels");
     return navigator;
   };
-
   /**
     Finds the list in the panels and opens up a new workspace from that list.
   */
@@ -134,7 +118,7 @@
       });
       assert.isTrue(widgetFound, "Cannot find widget for attr " + key + " in workspace " + workspace.kind);
       attribute = workspace.value.get(key);
-      if (attribute.idAttribute && !value.idAttribute) {
+      if (attribute && attribute.idAttribute && !value.idAttribute) {
         // the attribute has been turned into a model
         assert.equal(attribute.id, value[attribute.idAttribute]);
 
@@ -224,7 +208,7 @@
 
   exports.updateFirstModel = function (test) {
     it('should allow a trivial update to the first model of ' + test.kind, function (done) {
-      this.timeout(20 * 1000);
+      this.timeout(60 * 1000);
       navigateToExistingWorkspace(XT.app, test.kind, function (workspaceContainer) {
         var updateObj,
           statusChanged,
@@ -257,7 +241,7 @@
     var workspaceContainer,
       workspace;
     it('can get to a new workspace', function (done) {
-      this.timeout(10 * 1000);
+      this.timeout(60 * 1000);
       navigateToNewWorkspace(XT.app, spec.listKind, function (_workspaceContainer) {
         workspaceContainer = _workspaceContainer;
         done();
@@ -270,12 +254,12 @@
     });
     _.each(spec.beforeSaveUIActions || [], function (spec) {
       it(spec.it, function (done) {
-        this.timeout(20 * 1000);
+        this.timeout(60 * 1000);
         spec.action(workspace, done);
       });
     });
     it('can save the workspace', function (done) {
-      this.timeout(20 * 1000);
+      this.timeout(60 * 1000);
       if (spec.captureObject) {
         XG = XG || {};
         XG.capturedId = workspace.value.id;
@@ -284,7 +268,7 @@
     });
     _.each(spec.afterSaveUIActions || [], function (spec) {
       it(spec.it, function (done) {
-        this.timeout(20 * 1000);
+        this.timeout(60 * 1000);
         spec.action(workspace, done);
       });
     });
@@ -292,7 +276,7 @@
       return;
     }
     it('can delete the item from the list', function (done) {
-      this.timeout(20 * 1000);
+      this.timeout(60 * 1000);
       deleteFromList(XT.app, workspace.value, done);
     });
   };
